# KM3Flux

## About

KM3Flux is a collection of neutrino flux models + assorted utilities for
computing event weights.

## Install

This is developed on python 3.6. Lower versions (especially py2)
might or might not work.

Install the dependencies

* numpy 
* pandas
* h5py
* pytables 

In your python env, do

    pip install git+http://git.km3net.de/moritz/km3flux.git

or just clone the git repository and install via ``pip install .``
